// Copied from Netlify CLI so that we can access the user's auth token
// See: https://github.com/netlify/cli/blob/6f79b80f8c23bd68a14749fd71aa64064de9165b/src/utils/command-helpers.ts#L129
import getGlobalConfig from "./get-global-config.js";
/**
 * Get a netlify token from the env NETLIFY_AUTH_TOKEN or the global config (set by netlify login command)
 */
export const getToken = async () => {
    // 1. then Check ENV var
    const { NETLIFY_AUTH_TOKEN } = process.env;
    if (NETLIFY_AUTH_TOKEN && NETLIFY_AUTH_TOKEN !== "null") {
        return [NETLIFY_AUTH_TOKEN, "env"];
    }
    // 2. If no env var use global user setting
    const globalConfig = await getGlobalConfig();
    const userId = globalConfig.get("userId");
    const tokenFromConfig = globalConfig.get(`users.${userId}.auth.token`);
    if (tokenFromConfig) {
        return [tokenFromConfig, "config"];
    }
    return [null, "not found"];
};
//# sourceMappingURL=get-token.js.map