import chalk from "chalk";
import { ModelError } from "../model/error.js";
export class BridgePluginAPI {
    runningConnector;
    constructor(ConfiguredNetlifyConnector) {
        this.runningConnector = ConfiguredNetlifyConnector;
    }
    Error(message) {
        return new ModelError(message);
    }
    log(message, { symbolColor, symbol } = {}) {
        // Right now we output additional logs besides what connect/create ouput.
        // This is because we silence their logs during local dev due to running content-engine, stackbit/dev, and a frontend framework
        // all at once. That's very noisy. However in production (and in tests), the opposite is true. Now their logs are not silenced,
        // and ours are adding more noise. This can be used by Connect/Create (and tests!) to silence noisy logs
        if (process.env.SDK_SILENCE_EXTRA_CONNECTOR_LOGS === `true`)
            return;
        if (!symbolColor || !(symbolColor in chalk))
            symbolColor = `green`;
        if (!symbol)
            symbol = `->`;
        if (symbol.length === 1)
            symbol = `${symbol} `;
        const label = chalk.grey(this.runningConnector.slug);
        console.log(`${label} \n ${chalk[symbolColor](symbol)} ${message}\n`);
    }
}
//# sourceMappingURL=bridge.js.map