import type * as CSITypes from "@stackbit/types";
import { type ModelBuilder } from "./builder.js";
import { ModelField, ResolvedModelField, type ModelDefinition } from "./definition.js";
import { VisitorState } from "./walker.js";
import { Editor } from "./types.js";
export type ModelContext = {
    pathName: string;
    path: string[];
    isNonNull: boolean;
};
export type ModelFieldContext = {
    fieldName: string;
    path: string[];
    isNonNull: boolean;
};
export type ModelTreeContext = {
    path: string[];
    visitorState: VisitorState;
};
export type RuntimePlatform = `netlify-create` | `netlify-connect`;
export interface ModelTransformerImplementation {
    isVisualEditorType?: boolean;
    toConnectDefinition(context: ModelContext): string;
    toConnectFieldLocalizedDefinition(context: ModelContext): string;
    toConnectFieldDefinition(modelField: ResolvedModelField): string | null;
    toConnectSingleFieldDefinition(modelField: ResolvedModelField): string | null;
    toConnectListFieldDefinition(modelField: ResolvedModelField): string | null;
    toCreateDefinition(): unknown;
    toCreateSingleFieldDefinition(context: ResolvedModelField): unknown;
    toCreateListFieldDefinition(context: ResolvedModelField): unknown;
    toCreateSingleFieldValue(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toCreateSingleFieldValueLocalized(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toCreateListFieldValue(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toCreateListFieldValueLocalized(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toConnectSingleFieldValue(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toConnectSingleFieldValueLocalized(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toConnectListFieldValue(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toConnectListFieldValueLocalized(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    parseVisitedInputSingle(visited: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    parseVisitedInputList(visited: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
}
export declare class ModelTransformer implements ModelTransformerImplementation {
    protected builder: ModelBuilder;
    protected definition: ModelDefinition;
    isVisualEditorType: boolean;
    constructor(init: {
        builder: ModelBuilder;
        definition: ModelDefinition;
    });
    protected get runtimePlatform(): RuntimePlatform;
    inputNeedsDefaultLocalization(input: unknown): boolean;
    private defaultLocalizeFieldValue;
    private updateTreeContext;
    toOutputValue(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    private maybeVisitListValue;
    convertObjectLocaleValues<FieldValueType = any, ReturnFieldValueType = any>(localized: Record<string, FieldValueType>, convertValue: (value: FieldValueType, localeCode: string) => ReturnFieldValueType, _treeContext: ModelTreeContext): Record<string, ReturnFieldValueType>;
    private parseVisitedInputListLocalized;
    toOutputValueList(input: any, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    private maybeVisitSingleValue;
    private parseVisitedInputSingleLocalized;
    toOutputValueSingle(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toListFieldValue(input: unknown, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    protected notImplemented(methodName: string): Error;
    protected removeObjectKeysThatHaveNoFieldWithThatName(visited: any): Record<string, any>;
    protected toConnectFieldsDefinitionSDL(): string;
    modelFieldToGraphQlFieldType(modelField: ResolvedModelField, opts?: {
        proxyFrom: string;
        asTypeName?: string;
        linkFrom?: string;
    }): string;
    protected modelFieldToGraphQLFieldSDL(modelField: ResolvedModelField, opts?: {
        proxyFrom: string;
        asTypeName?: string;
        linkFrom?: string;
    }): string;
    private modelFieldToLinkDirective;
    private fieldToLocalizedDirective;
    protected fieldToLocaleProxyArg(modelField: ResolvedModelField, proxyFrom: string | undefined, locale: string | undefined): string;
    protected modelFieldToCreateGraphQLProxy(modelField: ResolvedModelField, proxyFrom?: string): string;
    protected editorProxyFrom(proxyFrom: string): string;
    protected proxyFrom(proxyFrom: string): string;
    protected modelFieldToSharedCreateProperties(modelField: ResolvedModelField): CSITypes.FieldCommonProps;
    protected modelFieldToSharedCreateNumberProperties(modelField: ResolvedModelField): CSITypes.FieldNumberProps;
    protected modelFieldToSharedControlType(field: ResolvedModelField): "slider" | "button-group" | "checkbox" | "dropdown" | undefined;
    toConnectDefinition(_ctx?: ModelContext): string;
    toConnectFieldLocalizedDefinition(_ctx?: ModelContext): string;
    toConnectFieldDefinition(modelField: ResolvedModelField): string | null;
    toConnectSingleFieldDefinition(_modelField: ResolvedModelField): string;
    toConnectListFieldDefinition(_modelField: ResolvedModelField): string;
    toCreateDefinition(): Editor.ObjectModel | Editor.PageModel | Editor.DataModel | null;
    toCreateFieldDefinition(modelField: ModelField, parentDefinition: ModelDefinition): null | CSITypes.Field | CSITypes.FieldList;
    toCreateSingleFieldDefinition(_modelField: ResolvedModelField): null | CSITypes.Field;
    toCreateListFieldDefinition(_modelField: ResolvedModelField): CSITypes.Field | null;
    toCreateSingleFieldValue(_input: unknown, _field: ResolvedModelField, _treeContext: ModelTreeContext): unknown;
    toCreateSingleFieldValueLocalized(_input: unknown, _field: ResolvedModelField, _treeContext: ModelTreeContext): unknown;
    toCreateListFieldValue(_input: unknown, _field: ResolvedModelField, _treeContext: ModelTreeContext): unknown;
    toCreateListFieldValueLocalized(input: Record<string, unknown>, field: ResolvedModelField, treeContext: ModelTreeContext): Editor.DocumentListFieldLocalized;
    toConnectSingleFieldValue(_input: unknown, _field: ResolvedModelField, _treeContext: ModelTreeContext): unknown;
    toConnectSingleFieldValueLocalized(input: Record<string, unknown>, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    toConnectListFieldValue(_input: unknown, _field: ResolvedModelField, _treeContext: ModelTreeContext): unknown;
    toConnectListFieldValueLocalized(input: Record<string, unknown>, field: ResolvedModelField, treeContext: ModelTreeContext): unknown;
    parseVisitedInputSingle(_visited: unknown, _field: ResolvedModelField, _treeContext: ModelTreeContext): unknown;
    parseVisitedInputList(_visited: unknown, _field: ResolvedModelField, _treeContext: ModelTreeContext): unknown;
}
//# sourceMappingURL=transformer.d.ts.map