import { AssetFields } from "@stackbit/types";
/**
 *
 * The types below are all taken from Netlify Create.
 * These are being inlined in order to make it easier for user
 * to see what's needed, and to also try and hide the seams
 * between Netlify Create (formerly known as Stackbit) and
 * the Netlify Connectors API.
 *
 * Types that have not been inlined are quite nested (e.g.: CSITypes.Cache)
 * so to avoid balloooning this file we're just starting with these and importing
 * the rest from the @stackbit/types package.
 */
export type ValidationError = {
    message: string;
    objectType: "document" | "asset";
    objectId: string;
    fieldPath: (string | number)[];
    isUniqueValidation?: boolean;
};
export type Asset<AssetContext = unknown> = {
    type: "asset";
    id: string;
    manageUrl: string;
    status: "added" | "modified" | "published" | "deleted";
    createdAt: string;
    createdBy?: string;
    updatedAt: string;
    updatedBy?: string[];
    locale?: string;
    fields: AssetFields;
    context: AssetContext;
    hidden?: boolean;
};
export type Locale = {
    code: string;
    default?: boolean;
};
export type User<UserContext = unknown> = {
    name: string;
    email: string;
    sso?: UserSSOProfile;
} & UserContext;
export type UserSSOProfile = {
    idpId: string;
    firstName?: string;
    lastName?: string;
    emails?: {
        value: string;
        type?: string;
        primary?: boolean;
    }[];
    attributes?: Record<string, any>;
};
//# sourceMappingURL=csi.d.ts.map